# vim: sw=4 ts=4 ft=perl

package WebService::Braintree::CreditCardDefaults;

use 5.010_001;
use strictures 1;

use constant CountryOfIssuance => 'USA';
use constant IssuingBank       => 'NETWORK ONLY';

1;
__END__
